@@ -147,14 +147,22 @@ while (max > 0)
   }
  else if (strncmp(inbuf,"n",1) == 0 )
   {
-  if ( !options.locknuts[PROCNT] ) options.pcprotein = 0 ;
+  if ( !options.locknuts[PROCNT] ) options.abnuts[PROCNT] = 0 ;
   if ( !options.locknuts[PROCNT] ) options.fatprotratio = 0 ;
-  if ( !options.locknuts[CHOCDF] ) options.pccarb = 0 ;
-  if ( !options.locknuts[PROCNT]) options.abnuts[PROCNT] = food_work.nutrient[PROCNT];
-  if ( !options.locknuts[CHOCDF]) options.abnuts[CHOCDF] = food_work.nutrient[CHOCDF];
+  if ( !options.locknuts[CHOCDF] ) options.abnuts[CHOCDF] = 0 ;
   if ( !options.locknuts[FIBTG]) options.abnuts[FIBTG] = food_work.nutrient[FIBTG];
-  if ( !options.locknuts[ENERC_KCAL]) newcal = food_work.nutrient[ENERC_KCAL];
-  if (  options.locknuts[ENERC_KCAL]) newcal = DV[ENERC_KCAL];
+  if ( !options.locknuts[ENERC_KCAL])
+   {
+   newcal = food_work.nutrient[ENERC_KCAL];
+   if ( !options.locknuts[PROCNT]) options.pcprotein = food_work.nutrient[PROT_KCAL] / food_work.nutrient[ENERC_KCAL] * 100;
+   if ( !options.locknuts[PROCNT]) options.pccarb = food_work.nutrient[CHO_KCAL] / food_work.nutrient[ENERC_KCAL] * 100;
+   }
+  if (  options.locknuts[ENERC_KCAL])
+   {
+   newcal = DV[ENERC_KCAL];
+   if ( !options.locknuts[PROCNT]) options.pcprotein = food_work.nutrient[PROT_KCAL] / DV[ENERC_KCAL] * 100;
+   if ( !options.locknuts[PROCNT]) options.pccarb = food_work.nutrient[CHO_KCAL] / DV[ENERC_KCAL] * 100;
+   }
   if ( options.fatprotratio > 0 && ( options.pcprotein > 0 || options.abnuts[PROCNT] > 0) ) options.abnuts[CHOCDF] = 0;
   auto_cal(&newcal,1);
   }
@@ -172,7 +180,7 @@ while (max > 0)
       DVMap[count+1] == FAMS || DVMap[count+1] == FAPU || 
       DVMap[count+1] == CHOLE || DVMap[count+1] == OMEGA6 ||
       DVMap[count+1] == CHO_NONFIB || DVMap[count+1] == OMEGA3 ||
-      DVMap[count+1] == CHOCDF || DVMap[count+1] == FIBTG ||
+      DVMap[count+1] == CHOCDF || 
       food_work.nutrient[DVMap[count+1]] >= DV[DVMap[count+1]]) deficpct[count] = 0;
    else 
     {
@@ -234,6 +242,7 @@ while (max > 0)
      if (strstr(food_ptr->name,"ALASKA NATIVE") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"CEREALS") != NULL && strstr(food_ptr->name,"RTE") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"INFANT FORMULA") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"INF FORMULA") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"CHILD FORMULA") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"ENSURE PLUS") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"BABYFOOD") != NULL) serving_ratio_abacus[abacuscount] = 0;
