@@ -130,12 +130,12 @@ DVBase[VITC] = 60;
 DVBase[FASAT] = 20;
 DVBase[CHOLE] = 300;
 DVBase[VITD] = 400;
-DVBase[LA] = 10;
-DVBase[AA] = .18;
+DVBase[LA] = 18.8;
+DVBase[AA] = 0.27;
 DVBase[OMEGA6] = DVBase[LA] + DVBase[AA];
-DVBase[ALA] = 2.22;
-DVBase[EPA] = 0.3;
-DVBase[DHA] = 0.3;
+DVBase[ALA] = 3.22;
+DVBase[EPA] = 0.37;
+DVBase[DHA] = 0.37;
 DVBase[OMEGA3] = DVBase[ALA] + DVBase[EPA] + DVBase[DHA];
 DVBase[FAPU] = DVBase[OMEGA6] + DVBase[OMEGA3];
 DVBase[FAMS] = 61.5 - DVBase[FASAT] - DVBase[FAPU];
@@ -509,7 +509,7 @@ char servingstring[62];
 int count;
 printf("%-60s   Grams  %8.2f\n",food_ptr->name,food_ptr->grams * *ratio);
 printf("Serving:  %-50s   Ounces  %7.2f\n",format_serving(servingstring,ratio,food_ptr),*ratio * food_ptr->grams / 28.35);
-printf("          %-50s   Water    %6.2f%%\n"," ",food_ptr->nutrient[WATER]);
+printf("          %-50s   Water    %6.2f%%\n"," ",food_ptr->nutrient[WATER] > 0 ? food_ptr->nutrient[WATER] : 0.0);
 if ( ! options.custom && options.screen == 0 ) printf("Percentages of \"Daily Values\" in this serving:                 Refuse   %3d%%\n\n",food_ptr->refuse);
 if ( options.custom && options.screen == 0 )     printf("Percentages of customized DV in this serving:                  Refuse   %3d%%\n\n",food_ptr->refuse);
 if ( options.screen > 0 )                 printf("Nutrients in this serving:                                     Refuse   %3d%%\n\n",food_ptr->refuse);
@@ -701,14 +701,16 @@ switch (options.screen)
  default :
  if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][1]])) fprintf(fp,"Calories(%4.0f)   %5.0f%%     ",DV[ScreenMap[options.screen][1]],food_work.nutrient[ScreenMap[options.screen][1]]/DV[ScreenMap[options.screen][1]]*100);
  else fprintf(fp,"Calories(%4.0f)    %5s     ",DV[ScreenMap[options.screen][1]],"(nd)");
- food_display_line(fp,ScreenMap[options.screen][14],1,0,0,0);
- food_display_line(fp,ScreenMap[options.screen][17],1,1,0,0);
+ if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][14]])) fprintf(fp,"%-14s   %5.0f%%     ",Nutrient[ScreenMap[options.screen][14]],dv_cho());
+ else fprintf(fp,"%-14s    %5s     ",Nutrient[ScreenMap[options.screen][14]],"(nd)");
+ if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][17]])) fprintf(fp,"%-14s   %5.0f%%\n",Nutrient[ScreenMap[options.screen][17]],dv_pro());
+ else fprintf(fp,"%-14s    %5s\n",Nutrient[ScreenMap[options.screen][17]],"(nd)");
  fprintf(fp,"Carb/Prot/Fat  %8s     ",carbprotfat);
  food_display_line(fp,ScreenMap[options.screen][15],1,0,0,0);
  if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][16]])) fprintf(fp,"%-15s  %5.0f%-1s\n",Nutrient[ScreenMap[options.screen][16]],food_work.nutrient[ScreenMap[options.screen][16]],Unit[ScreenMap[options.screen][16]]);
  else fprintf(fp,"%-15s   %5s\n",Nutrient[ScreenMap[options.screen][16]],"(nd)");
  fprintf(fp,"\n");
- if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][2]])) fprintf(fp,"%-14s   %5.0f%%     ",Nutrient[ScreenMap[options.screen][2]],food_work.nutrient[ScreenMap[options.screen][2]]/dv_fat()*100);
+ if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][2]])) fprintf(fp,"%-14s   %5.0f%%     ",Nutrient[ScreenMap[options.screen][2]],dv_fat());
  else fprintf(fp,"%-14s    %5s     ",Nutrient[ScreenMap[options.screen][2]],"(nd)");
  food_display_line(fp,ScreenMap[options.screen][18],1,0,0,0);
  food_display_line(fp,ScreenMap[options.screen][30],1,1,0,0);
@@ -888,13 +890,12 @@ else
  }
 food_ptr->nutrient[CHO_NONFIB] = food_ptr->nutrient[CHOCDF] - food_ptr->nutrient[FIBTG];
 if (food_ptr->nutrient[CHO_NONFIB] < 0) food_ptr->nutrient[CHO_NONFIB] = 0;
-if (food_ptr->nutrient[FIBTG] == 0 && test_for_negative_zero(&food_ptr->nutrient[FIBTG])) food_ptr->nutrient[CHO_NONFIB] = NoData;
 }
 
 float dv_fams()
 {
 float targetpct, totalfa, totaldv, imaginarydv, diff;
-targetpct = food_work.nutrient[FAT] / dv_fat();
+targetpct = dv_fat() / 100;
 totalfa = food_work.nutrient[FASAT] + food_work.nutrient[FAMS] + food_work.nutrient[FAPU];
 totaldv = DV[FASAT] + DV[FAMS] + DV[FAPU];
 imaginarydv = totalfa / targetpct;
@@ -907,12 +908,28 @@ float dv_fat()
 {
 float targetpct, totalcal, totaldv, imaginarydv, diff;
 targetpct = food_work.nutrient[ENERC_KCAL] / DV[ENERC_KCAL];
-totalcal = food_work.nutrient[PROCNT] * options.protcalpergm + food_work.nutrient[CHOCDF] * options.carbcalpergm + food_work.nutrient[FAT] * options.fatcalpergm;
-totaldv = DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm + DV[FAT] * options.fatcalpergm;
-imaginarydv = totalcal / targetpct;
-diff = (totaldv - imaginarydv) / options.fatcalpergm;
-if (DV[FAT] > diff) return DV[FAT] - diff;
-else return DV[FAT];
+if (options.pccarb == 0 && options.pcprotein == 0)
+ {
+ totalcal = food_work.nutrient[PROCNT] * options.protcalpergm + food_work.nutrient[CHOCDF] * options.carbcalpergm + food_work.nutrient[FAT] * options.fatcalpergm;
+ totaldv = DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm + DV[FAT] * options.fatcalpergm;
+ imaginarydv = totalcal / targetpct;
+ diff = (totaldv - imaginarydv) / options.fatcalpergm;
+ if (DV[FAT] > diff) return DV[FAT] - diff;
+ else return DV[FAT];
+ }
+else return diff = 100 * food_work.nutrient[FAT_KCAL] / (DV[ENERC_KCAL] * (1 - (options.pccarb > 0 ? options.pccarb / 100 : DV[CHOCDF] * options.carbcalpergm / DV[ENERC_KCAL]) - (options.pcprotein > 0 ? options.pcprotein / 100 : DV[PROCNT] * options.protcalpergm / DV[ENERC_KCAL])));
+}
+
+float dv_cho()
+{
+if (options.pccarb > 0) return food_work.nutrient[CHO_KCAL] / DV[ENERC_KCAL] / options.pccarb * 10000;
+else return food_work.nutrient[CHOCDF] / DV[CHOCDF] * 100;
+}
+
+float dv_pro()
+{
+if (options.pcprotein > 0) return food_work.nutrient[PROT_KCAL] / DV[ENERC_KCAL] / options.pcprotein * 10000;
+else return food_work.nutrient[PROCNT] / DV[PROCNT] * 100;
 }
 
 char *format_serving(char *buffer, float *ratio, struct food *food_ptr)
