@@ -84,6 +84,8 @@ void delete_recipe_food(int);
 void compute_derived_fields(struct food *);
 float dv_fams(void);
 float dv_fat(void);
+float dv_cho(void);
+float dv_pro(void);
 char *format_serving(char *, float *, struct food *);
 
 #endif
