@@ -223,6 +223,7 @@ if ( options.fatprotratio > 0 )
   options.abnuts[CHOCDF] = 0;
   options.locknuts[CHOCDF] = 0;
   }
+ else if (options.abnuts[CHOCDF] == 0 && options.pccarb == 0) options.pcprotein = 30 / options.fatprotratio;
  }
 options.abnuts[FAT] = 0;
 options.locknuts[FAT] = 0;
@@ -369,7 +370,7 @@ fgets(buff,128,stdin);
 
 void auto_cal(float *bufptr, int analflag)
 {
-float buf = *bufptr, temp = 0, adjaa = .15, adjsat = 1.5, adjla = .15;
+float buf = *bufptr, temp = 0;
 int i;
 if (options.autocal) buf = average_cals(analflag);
 if (analflag)
@@ -401,6 +402,9 @@ if (buf == 1)
  DV[PROCNT] = DVBase[PROCNT];
  DV[FAT] = DVBase[FAT];
  DV[CHOCDF] = DVBase[CHOCDF];
+ options.protcalpergm = 4;
+ options.carbcalpergm = 4;
+ options.fatcalpergm = 9.2307692;
  }
 DV[FIBTG] = buf * DVBase[FIBTG];
 DV[FASAT] = buf * DVBase[FASAT];
@@ -432,7 +436,7 @@ if (options.fatprotratio > 0 && (options.abnuts[PROCNT] > 0 || options.pcprotein
  temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[FAT] * options.fatcalpergm) / DV[ENERC_KCAL];
  DV[CHOCDF] = temp * DV[ENERC_KCAL] / options.carbcalpergm;
  }
-if (options.fatprotratio <= 0)
+if (options.fatprotratio <= 0 && buf != 1)
  {
  temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm) / DV[ENERC_KCAL];
  DV[FAT] = temp * DV[ENERC_KCAL] / options.fatcalpergm;
@@ -481,23 +485,14 @@ if (options.abnuts[K] > 0) DV[K] = options.abnuts[K];
 if (options.abnuts[SE] > 0) DV[SE] = options.abnuts[SE]; 
 if (options.abnuts[NA] > 0) DV[NA] = options.abnuts[NA]; 
 if (options.abnuts[ZN] > 0) DV[ZN] = options.abnuts[ZN]; 
-DV[CHO_NONFIB] = DV[CHOCDF] - DV[FIBTG] < 0 ? 0 : DV[CHOCDF] - DV[FIBTG];
-if (DV[FAT] / DVBase[FAT] > DV[ENERC_KCAL] / DVBase[ENERC_KCAL])
+if (! options.abnuts[CHO_NONFIB]) DV[CHO_NONFIB] = DV[CHOCDF] - DV[FIBTG] < 0 ? 0 : DV[CHOCDF] - DV[FIBTG];
+else DV[CHO_NONFIB] = options.abnuts[CHO_NONFIB];
+temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm) / DV[ENERC_KCAL];
+if (temp > .32 && options.pcsatfat <= 0 && options.abnuts[FASAT] <= 0 && options.abnuts[FAMS] <= 0) 
  {
- temp = -1 + ((DV[FAT] / DVBase[FAT]) / (DV[ENERC_KCAL] / DVBase[ENERC_KCAL]));
- if (options.abnuts[FAPU] <= 0) DV[FAPU] += temp * adjla * DV[LA];
- if (options.abnuts[FAPU] <= 0) DV[FAPU] += temp * adjaa * DV[AA];
- if (options.abnuts[OMEGA6] <= 0) DV[OMEGA6] += temp * adjla * DV[LA];
- if (options.abnuts[OMEGA6] <= 0) DV[OMEGA6] += temp * adjaa * DV[AA];
- if (options.abnuts[FAMS] <= 0) DV[FAMS] -= temp * adjla * DV[LA];
- if (options.abnuts[FAMS] <= 0) DV[FAMS] -= temp * adjaa * DV[AA];
- if (options.abnuts[LA] <= 0) DV[LA] += temp * adjla * DV[LA];
- if (options.abnuts[AA] <= 0) DV[AA] += temp * adjaa * DV[AA];
- if (options.pcsatfat <= 0 && options.abnuts[FASAT] <= 0)
-  {
-  if (options.abnuts[FAMS] <= 0) DV[FAMS] -= temp * adjsat * DV[FASAT];
-  DV[FASAT] += temp * adjsat * DV[FASAT];
-  }
+ temp = DV[FAMS] + DV[FASAT];
+ DV[FASAT] = 0.42 * temp;
+ DV[FAMS] = temp - DV[FASAT];
  }
 if ( options.pcsatfat > 0 || options.pcprotein > 0 || options.pccarb > 0 || options.fatprotratio || options.abnuts[PROCNT] > 0 || options.abnuts[CHOCDF] > 0 || options.abnuts[FIBTG] > 0 || options.abnuts[VITE]) options.custom = 1;
 else options.custom = 0;
